/******************************************************************************\
* $Id: _scenario_view.sas,v 1.1.2.6.4.3 2012/03/23 14:51:34 stuhor Exp $
*
* Copyright(c) 2011 SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
*
* Name: _scenario_view.sas
*
* Purpose: Creates table _scenario_view.  This table provides information
* about scenarios to other processes.
*
* Author: stuhor
*
* Support: SAS(r) Solutions OnDemand
*
* Input:
*
* Output:   _scenario_view.sas7bdat
*
* Parameters: (if applicable)
*
* Dependencies/Assumptions:     FCM.FCM_PROJECT,
*                               FCM.FCM_SCENARIO_GROUP,
*                               FCM.FCM_SCENARIO,
*                               FCM.FCM_PREP_TABLE,
*                               FCM.FCM_SCENARIO_GROUP,
*                               FCM.FCM_ENTITY_VAR,
*                               recipient_view
* Usage:
*
* ddmmmyyyy userid description (Change Code)
* History: Initial check in
\******************************************************************************/

proc sql noprint;
create table _scenario_view_temp as
select	PROJ.PROJECT_SK,
		PROJ.RECIPIENT_TYPE_CD label='PROJ_RECIPIENT_TYPE_CD' as PROJ_RECIPIENT_TYPE_CD,
		PROJ.RECIPIENT_ID label='PROJ_RECIPIENT_ID' as PROJ_RECIPIENT_ID,
		PROJ.SUPPRESSION_GROUP_RK label='PROJ_SUPPRESSION_GROUP_RK' as PROJ_SUPPRESSION_GROUP_RK,
		PROJ.ROUTING_GROUP_RK label='PROJ_ROUTING_GROUP_RK' as PROJ_ROUTING_GROUP_RK,
		PROJ.SUPPRESSION_MS_NO label='PROJ_SUPPRESSION_MS_NO' as PROJ_SUPPRESSION_MS_NO,
		PROJ.RUN_FREQUENCY_TYPE_CD label='P_RUN_FREQUENCY_TYPE_CD' as P_RUN_FREQUENCY_TYPE_CD,

		SCENARIO.SCENARIO_GROUP_RK,
		SCENARIO.SCENARIO_SK,
		SCENARIO.LOGICAL_DELETE_FLG,
		SCENARIO.LOGICAL_RK,
		SCENARIO.LOGICAL_RK label='SCENARIO_RK' as SCENARIO_RK,
		SCENARIO.PREP_TABLE_RK,
		SCENARIO.ENTITY_RK,
		SCENARIO.ENTITY_VARIABLE_RK,
		SCENARIO.SCENARIO_NM,
		SCENARIO.SCENARIO_DESC,
		SCENARIO.SCENARIO_RUN_ORDER_NO,
		SCENARIO.SCENARIO_SEVERITY_SCORE_NO,
		SCENARIO.SCENARIO_WEIGHT_NO,
		SCENARIO.SCENARIO_TYPE_CD,
		SCENARIO.SCENARIO_PURPOSE_CD,
		SCENARIO.DATA_PROCESSING_TYPE_CD label='S_DATA_PROCESSING_TYPE_CD' as S_DATA_PROCESSING_TYPE_CD,
	    SCENARIO.SAS_FILE_PATH_NM,
	    SCENARIO.SCENARIO_STATUS_CD,
		SCENARIO.RECIPIENT_TYPE_CD label='S_RECIPIENT_TYPE' as S_RECIPIENT_TYPE,
		SCENARIO.RECIPIENT_ID label='S_RECIPIENT_ID' as S_RECIPIENT_ID,
		SCENARIO.RULE_FORMULA,
		SCENARIO.ROUTING_GROUP_RK label='S_ROUTING_GROUP_RK' as S_ROUTING_GROUP_RK,
		SCENARIO.SUPPRESSION_GROUP_RK label='S_SUPPRESSION_GROUP_RK' as S_SUPPRESSION_GROUP_RK,
		SCENARIO.DEFAULT_SUPPRESS_MS_NO,
		SCENARIO.RUN_FREQUENCY_TYPE_CD label='S_RUN_FREQUENCY_TYPE_CD' as S_RUN_FREQUENCY_TYPE_CD,

		case(compress(SCENARIO.DATA_PROCESSING_TYPE_CD))
			when '' then SCENARIO_GRP.DATA_PROCESSING_TYPE_CD
			else SCENARIO.DATA_PROCESSING_TYPE_CD
		end as DATA_PROCESS_TYPE_CD,

		SCENARIO_GRP.PROJECT_RK,
		SCENARIO_GRP.LOGICAL_RK,
		SCENARIO_GRP.SCENARIO_GROUP_NM,
		SCENARIO_GRP.SCENARIO_GROUP_DESC,
		SCENARIO_GRP.GROUP_TYPE_CD,
		SCENARIO_GRP.SCENARIO_GROUP_PURPOSE_CD,
		SCENARIO_GRP.DATA_PROCESSING_TYPE_CD label='GRP_DATA_PROCESSING_TYPE_CD' as GRP_DATA_PROCESSING_TYPE_CD,
		SCENARIO_GRP.RECIPIENT_TYPE_CD label='GRP_RECIPIENT_TYPE_CD' as GRP_RECIPIENT_TYPE_CD,
		SCENARIO_GRP.RECIPIENT_ID label='GRP_RECIPIENT_ID' as GRP_RECIPIENT_ID,
		SCENARIO_GRP.CUSTOM_HEADER_FILE_PATH,
		SCENARIO_GRP.CUSTOM_FOOTER_FILE_PATH,
		SCENARIO_GRP.PRE_PROCESS_FILE_PATH,
		SCENARIO_GRP.POST_PROCESS_FILE_PATH,
		SCENARIO_GRP.ROUTING_GROUP_RK label='GRP_ROUTING_GROUP_RK' as GRP_ROUTING_GROUP_RK,
		SCENARIO_GRP.SUPPRESSION_GROUP_RK label='GRP_SUPPRESSION_GRP_RK' as GRP_SUPPRESSION_GRP_RK,
		SCENARIO_GRP.RUN_FREQUENCY_TYPE_CD label='GRP_RUN_FREQUENCY_TYPE_CD' as GRP_RUN_FREQUENCY_TYPE_CD,
		SCENARIO_GRP.SUPPRESSION_MS_NO label='GRP_SUPPRESSION_MS_NO' as GRP_SUPPRESSION_MS_NO,

		put(SCENARIO_GRP.SCENARIO_GROUP_PURPOSE_CD, $scenario_group_purpose_cd.) as SCENARIO_GRP_PURPOSE_CD,
		put(SCENARIO.SCENARIO_PURPOSE_CD,$scenario_purpose_cd.) as SCEN_PURPOSE_CD,

		AE.ENTITY_SK,
		AE.ENTITY_NM,
	    
		EV.VARIABLE_NM,

		CAL.CALENDAR_DT,
		CAL.RUNDATE_FLG,
		CAL.INTRA_DAY_FLG,
		CAL.DAILY_RUN_FLG,
		CAL.WEEKLY_RUN_FLG,
		CAL.MONTHLY_RUN_FLG,
		CAL.STATUS_FLG,

		case
			when compress(SCENARIO.RECIPIENT_ID)='' and
				 compress(SCENARIO_GRP.RECIPIENT_ID)='' then PROJ.RECIPIENT_ID
			when compress(SCENARIO.RECIPIENT_ID)='' and
				 compress(SCENARIO_GRP.RECIPIENT_ID)~='' then SCENARIO_GRP.RECIPIENT_ID
			else SCENARIO.RECIPIENT_ID
		end as RECIPIENT_ID,

		case
			when compress(SCENARIO.RECIPIENT_TYPE_CD)='' and
				 compress(SCENARIO_GRP.RECIPIENT_TYPE_CD)='' then PROJ.RECIPIENT_TYPE_CD
			when compress(SCENARIO.RECIPIENT_TYPE_CD)='' and
				 compress(SCENARIO_GRP.RECIPIENT_TYPE_CD)~='' then SCENARIO_GRP.RECIPIENT_TYPE_CD
			else SCENARIO.RECIPIENT_TYPE_CD
		end as RECIPIENT_TYPE_CD,

		case
			when compress(SCENARIO.SEGMENT_ID)='' and
				 compress(SCENARIO_GRP.SEGMENT_ID)='' then PROJ.SEGMENT_ID
			when compress(SCENARIO.SEGMENT_ID)='' and
				 compress(SCENARIO_GRP.SEGMENT_ID)~='' then SCENARIO_GRP.SEGMENT_ID
			else SCENARIO.SEGMENT_ID
		end as SEGMENT_ID,

		case
			when compress(SCENARIO.SUPPRESSION_GROUP_RK)='' and
				 compress(SCENARIO_GRP.SUPPRESSION_GROUP_RK)='' then PROJ.SUPPRESSION_GROUP_RK
			when compress(SCENARIO.SUPPRESSION_GROUP_RK)='' and
				 compress(SCENARIO_GRP.SUPPRESSION_GROUP_RK)~='' then SCENARIO_GRP.SUPPRESSION_GROUP_RK
			else SCENARIO.SUPPRESSION_GROUP_RK
		end as SUPPRESSION_GRP_RK,

		case
			when compress(SCENARIO.ROUTING_GROUP_RK)='' and
				 compress(SCENARIO_GRP.ROUTING_GROUP_RK)='' then PROJ.ROUTING_GROUP_RK
			when compress(SCENARIO.ROUTING_GROUP_RK)='' and
				 compress(SCENARIO_GRP.ROUTING_GROUP_RK)~='' then SCENARIO_GRP.ROUTING_GROUP_RK
			else SCENARIO.ROUTING_GROUP_RK
		end as ROUTING_GRP_RK,

		case
			when SCENARIO_GRP.SUPPRESSION_MS_NO =. then PROJ.SUPPRESSION_MS_NO
			else SCENARIO_GRP.SUPPRESSION_MS_NO
		end as SUPPRESS_MS_NO
		
		
	from	&libref..FCM_JOB_CALENDAR as CAL,
			&libref..FCM_PROJECT as PROJ,
			&libref..FCM_SCENARIO_GROUP as SCENARIO_GRP,
			&libref..FCM_SCENARIO as SCENARIO
	        
	left join &libref..FCM_ENTITY_VAR as EV
		on 	SCENARIO.ENTITY_VARIABLE_RK = EV.LOGICAL_RK and
			EV.LOGICAL_DELETE_FLG=SCENARIO.LOGICAL_DELETE_FLG

	left join &libref..FCM_ENTITY as AE
		on	AE.LOGICAL_RK = SCENARIO.ENTITY_RK and 
			AE.LOGICAL_DELETE_FLG=SCENARIO.LOGICAL_DELETE_FLG	

	where	SCENARIO.SCENARIO_GROUP_RK=SCENARIO_GRP.LOGICAL_RK and
			SCENARIO_GRP.PROJECT_RK= PROJ.LOGICAL_RK and
			SCENARIO_GRP.LOGICAL_DELETE_FLG=SCENARIO.LOGICAL_DELETE_FLG and
			PROJ.LOGICAL_DELETE_FLG = SCENARIO.LOGICAL_DELETE_FLG and
			SCENARIO.LOGICAL_DELETE_FLG='N' and
			(
				%eval(&FCM_RUNPRJ=ALL)
				or
				LEFT(TRIM(PROJ.LOGICAL_RK)) = "&FCM_RUNPRJ"        
			) and
			CAL.CALENDAR_DT = %sysevalf("&FCM_RUNDATE"dt) and
		
			case
				when SCENARIO.SCENARIO_PURPOSE_CD ^= 'SC' then SCENARIO.SCENARIO_STATUS_CD='A'
				when SCENARIO.SCENARIO_PURPOSE_CD = 'SC' then SCENARIO.SCENARIO_STATUS_CD in ('I', 'A')
			else
				SCENARIO.SCENARIO_STATUS_CD='A'
			end

			and
			(
				(
					%eval(&FCM_INTRADAYONLY = 0 ) and
					CAL.RUNDATE_FLG='1' and
					CAL.STATUS_FLG='0' and
					(
						(
							CAL.WEEKLY_RUN_FLG ='1' and
							SCENARIO.RUN_FREQUENCY_TYPE_CD = 'W' 
						)
						or
						(
							CAL.DAILY_RUN_FLG ='1' and
							SCENARIO.RUN_FREQUENCY_TYPE_CD = 'D' 
						)
						or
						(
							CAL.MONTHLY_RUN_FLG ='1' and
							SCENARIO.RUN_FREQUENCY_TYPE_CD = 'M'
						)
					)
				)
				or 
				(
					(
						%eval(&FCM_INTRADAYONLY = 1) and
						CAL.INTRA_DAY_FLG ='1' and
						SCENARIO.RUN_FREQUENCY_TYPE_CD = 'I' 
					)
				)
				or
				( 
					SCENARIO.SCENARIO_PURPOSE_CD = "SP" or
					SCENARIO.SCENARIO_PURPOSE_CD = "SC" or
					SCENARIO.SCENARIO_PURPOSE_CD = "RT"
				)
			)

	order by	SCENARIO_GRP.PROJECT_RK,
				SCENARIO_GRP_PURPOSE_CD,
				PREP_TABLE_RK,
				GROUP_TYPE_CD,
				DATA_PROCESS_TYPE_CD,
				SCEN_PURPOSE_CD,
				SCENARIO_TYPE_CD,
				SCENARIO_RUN_ORDER_NO
;
quit;

/* Remove scoring scenarios that do not have an active associated F or R alert */
proc sql;
	create table _scenario_view as
	select *
	from _scenario_view_temp
	where project_sk in (select project_sk
						 from _scenario_view_temp
						 where  scenario_status_cd = 'A' and
						 		scenario_purpose_cd in ('F','RK'));
quit;

/* Drop temporary table */
proc sql;
	drop table _scenario_view_temp;
quit;
