/******************************************************************************\
* $Id: job_calendar_check.sas,v 1.1.6.1 2012/04/17 14:44:46 stuhor Exp $
*
* Copyright(c) 2011 SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
*
* Name:  job_calendar_check.sas
*
* Purpose: Ensure FCM.FCM_JOB_CALENDAR have entries in valid format
*
* Author: stuhor
*
* Support: SAS(r) Solutions OnDemand
*
* Input:   None
* 
* Output:  None
*
* Parameters:
*
* Dependencies/Assumptions: 
*
* Usage:  
*
* History:
* ddmmmyyyy userid	description (Change Code)
\******************************************************************************/

%macro job_calendar_check;
	%let macroname=%get_macroname;
	%put NOTE:(FCM) Entering &macroname;

	data temp1;
		set FCM.FCM_JOB_CALENDAR;
		format dt_part date9. tm_part tod8.2;
		dt_part = datepart(calendar_dt);
		tm_part = timepart(calendar_dt);
	run;

	proc sort data=temp1 dupout=STAGE.JOB_CAL_DT_ERROR nodupkey;
		by dt_part;
	run;

	%if %sfs_util_nobs(STAGE.JOB_CAL_DT_ERROR) > 0 %then %do;
		%put ERROR:(FCM): Duplicate entries for the same calendar date are not allowed. See STAGE.JOB_CAL_DT_ERROR table. AGP will not be run.;
	%end;

	data STAGE.JOB_CAL_TM_ERROR;
		set temp1;
		if tm_part ^= 0 then output; 
	run;

	%if %sfs_util_nobs(STAGE.JOB_CAL_TM_ERROR) > 0 %then %do;
		%put ERROR:(FCM): Time entries other than 00:00:00 are not allowed. See STAGE.JOB_CAL_TM_ERROR. AGP will not be run.;
	%end;

	%if (%sfs_util_nobs(STAGE.JOB_CAL_DT_ERROR) > 0) or (%sfs_util_nobs(STAGE.JOB_CAL_TM_ERROR) > 0) %then %do;
		%abort cancel;
	%end;

	proc sql;
		drop table temp1;
		drop table STAGE.JOB_CAL_DT_ERROR;
		drop table STAGE.JOB_CAL_TM_ERROR;
	quit;

	%let macroname=%get_macroname;
	%put NOTE:(FCM) Exiting &macroname;
%mend job_calendar_check;
